@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_CHOKING_EVENT_H_
-#define _D_BT_CHOKING_EVENT_H_
+#ifndef D_BT_CHOKING_EVENT_H
+#define D_BT_CHOKING_EVENT_H
 
 #include "common.h"
 
@@ -43,4 +43,4 @@ class BtChokingEvent {};
 
 } // namespace aria2
 
-#endif // _D_BT_CHOKING_EVENT_H_
+#endif // D_BT_CHOKING_EVENT_H
