@@ -43,7 +43,6 @@ namespace aria2 {
 class DownloadContext;
 class Peer;
 class PeerStorage;
-class BtRuntime;
 class DHTGetPeersReplyMessage;
 
 class DHTPeerLookupTask:
@@ -51,28 +50,29 @@ class DHTPeerLookupTask:
 private:
   std::map<std::string, std::string> tokenStorage_;
 
-  SharedHandle<PeerStorage> peerStorage_;
-
-  SharedHandle<BtRuntime> btRuntime_;
+  std::shared_ptr<PeerStorage> peerStorage_;
+  uint16_t tcpPort_;
 public:
-  DHTPeerLookupTask(const SharedHandle<DownloadContext>& downloadContext);
+  DHTPeerLookupTask
+  (const std::shared_ptr<DownloadContext>& downloadContext,
+   uint16_t tcpPort);
 
   virtual void getNodesFromMessage
-  (std::vector<SharedHandle<DHTNode> >& nodes,
-   const DHTGetPeersReplyMessage* message);
-  
-  virtual void onReceivedInternal(const DHTGetPeersReplyMessage* message);
-  
-  virtual SharedHandle<DHTMessage> createMessage
-  (const SharedHandle<DHTNode>& remoteNode);
+  (std::vector<std::shared_ptr<DHTNode>>& nodes,
+   const DHTGetPeersReplyMessage* message) CXX11_OVERRIDE;
 
-  virtual SharedHandle<DHTMessageCallback> createCallback();
+  virtual void onReceivedInternal(const DHTGetPeersReplyMessage* message)
+    CXX11_OVERRIDE;
 
-  virtual void onFinish();
-  
-  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+  virtual std::unique_ptr<DHTMessage> createMessage
+  (const std::shared_ptr<DHTNode>& remoteNode) CXX11_OVERRIDE;
 
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+  virtual std::unique_ptr<DHTMessageCallback> createCallback()
+    CXX11_OVERRIDE;
+
+  virtual void onFinish() CXX11_OVERRIDE;
+
+  void setPeerStorage(const std::shared_ptr<PeerStorage>& peerStorage);
 };
 
 } // namespace aria2
