@@ -95,53 +95,53 @@ const char VLB_COMPLETE[] = "complete";
 const char VLB_USED[] = "used";
 const char VLB_ZERO[] = "0";
 
-const std::string KEY_GID = "gid";
-const std::string KEY_ERROR_CODE = "errorCode";
-const std::string KEY_STATUS = "status";
-const std::string KEY_TOTAL_LENGTH = "totalLength";
-const std::string KEY_COMPLETED_LENGTH = "completedLength";
-const std::string KEY_DOWNLOAD_SPEED = "downloadSpeed";
-const std::string KEY_UPLOAD_SPEED = "uploadSpeed";
-const std::string KEY_UPLOAD_LENGTH = "uploadLength";
-const std::string KEY_CONNECTIONS = "connections";
-const std::string KEY_BITFIELD = "bitfield";
-const std::string KEY_PIECE_LENGTH = "pieceLength";
-const std::string KEY_NUM_PIECES = "numPieces";
-const std::string KEY_FOLLOWED_BY = "followedBy";
-const std::string KEY_BELONGS_TO = "belongsTo";
-const std::string KEY_INFO_HASH = "infoHash";
-const std::string KEY_NUM_SEEDERS = "numSeeders";
-const std::string KEY_PEER_ID = "peerId";
-const std::string KEY_IP = "ip";
-const std::string KEY_PORT = "port";
-const std::string KEY_AM_CHOKING = "amChoking";
-const std::string KEY_PEER_CHOKING = "peerChoking";
-const std::string KEY_SEEDER = "seeder";
-const std::string KEY_INDEX = "index";
-const std::string KEY_PATH = "path";
-const std::string KEY_SELECTED = "selected";
-const std::string KEY_LENGTH = "length";
-const std::string KEY_URI = "uri";
-const std::string KEY_CURRENT_URI = "currentUri";
-const std::string KEY_VERSION = "version";
-const std::string KEY_ENABLED_FEATURES = "enabledFeatures";
-const std::string KEY_METHOD_NAME = "methodName";
-const std::string KEY_PARAMS = "params";
-const std::string KEY_SESSION_ID = "sessionId";
-const std::string KEY_FILES = "files";
-const std::string KEY_DIR = "dir";
-const std::string KEY_URIS = "uris";
-const std::string KEY_BITTORRENT = "bittorrent";
-const std::string KEY_INFO = "info";
-const std::string KEY_NAME = "name";
-const std::string KEY_ANNOUNCE_LIST = "announceList";
-const std::string KEY_COMMENT = "comment";
-const std::string KEY_CREATION_DATE = "creationDate";
-const std::string KEY_MODE = "mode";
-const std::string KEY_SERVERS = "servers";
-const std::string KEY_NUM_WAITING = "numWaiting";
-const std::string KEY_NUM_STOPPED = "numStopped";
-const std::string KEY_NUM_ACTIVE = "numActive";
+const char KEY_GID[] = "gid";
+const char KEY_ERROR_CODE[] = "errorCode";
+const char KEY_STATUS[] = "status";
+const char KEY_TOTAL_LENGTH[] = "totalLength";
+const char KEY_COMPLETED_LENGTH[] = "completedLength";
+const char KEY_DOWNLOAD_SPEED[] = "downloadSpeed";
+const char KEY_UPLOAD_SPEED[] = "uploadSpeed";
+const char KEY_UPLOAD_LENGTH[] = "uploadLength";
+const char KEY_CONNECTIONS[] = "connections";
+const char KEY_BITFIELD[] = "bitfield";
+const char KEY_PIECE_LENGTH[] = "pieceLength";
+const char KEY_NUM_PIECES[] = "numPieces";
+const char KEY_FOLLOWED_BY[] = "followedBy";
+const char KEY_BELONGS_TO[] = "belongsTo";
+const char KEY_INFO_HASH[] = "infoHash";
+const char KEY_NUM_SEEDERS[] = "numSeeders";
+const char KEY_PEER_ID[] = "peerId";
+const char KEY_IP[] = "ip";
+const char KEY_PORT[] = "port";
+const char KEY_AM_CHOKING[] = "amChoking";
+const char KEY_PEER_CHOKING[] = "peerChoking";
+const char KEY_SEEDER[] = "seeder";
+const char KEY_INDEX[] = "index";
+const char KEY_PATH[] = "path";
+const char KEY_SELECTED[] = "selected";
+const char KEY_LENGTH[] = "length";
+const char KEY_URI[] = "uri";
+const char KEY_CURRENT_URI[] = "currentUri";
+const char KEY_VERSION[] = "version";
+const char KEY_ENABLED_FEATURES[] = "enabledFeatures";
+const char KEY_METHOD_NAME[] = "methodName";
+const char KEY_PARAMS[] = "params";
+const char KEY_SESSION_ID[] = "sessionId";
+const char KEY_FILES[] = "files";
+const char KEY_DIR[] = "dir";
+const char KEY_URIS[] = "uris";
+const char KEY_BITTORRENT[] = "bittorrent";
+const char KEY_INFO[] = "info";
+const char KEY_NAME[] = "name";
+const char KEY_ANNOUNCE_LIST[] = "announceList";
+const char KEY_COMMENT[] = "comment";
+const char KEY_CREATION_DATE[] = "creationDate";
+const char KEY_MODE[] = "mode";
+const char KEY_SERVERS[] = "servers";
+const char KEY_NUM_WAITING[] = "numWaiting";
+const char KEY_NUM_STOPPED[] = "numStopped";
+const char KEY_NUM_ACTIVE[] = "numActive";
 } // namespace
 
 namespace {
